Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4071)

Unified Diff: chrome/browser/resources/vr_shell/vr_shell_ui.js

Issue 2710593008: [VR Shell] Fix hidden elements being hit-testable. (Closed)
Patch Set: Fix closure compiler error Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/vr_shell/vr_shell_ui.js
diff --git a/chrome/browser/resources/vr_shell/vr_shell_ui.js b/chrome/browser/resources/vr_shell/vr_shell_ui.js
index a6eedc1c17176e7827b40c024fb323788f347fc6..de421682b76de8b9c9d1a82e9c8b6d768d94cd5f 100644
--- a/chrome/browser/resources/vr_shell/vr_shell_ui.js
+++ b/chrome/browser/resources/vr_shell/vr_shell_ui.js
@@ -51,14 +51,14 @@ var vrShellUi = (function() {
element.setTranslation(0, 0, -this.BROWSING_SCREEN_DISTANCE);
this.elementId = ui.addElement(element);
// Place an invisible but hittable plane behind the content quad, to keep
// the reticle roughly planar with the content if near content.
let backPlane = new api.UiElement(0, 0, 0, 0);
- backPlane.setVisible(false);
- backPlane.setHitTestable(true);
backPlane.setSize(1000, 1000);
backPlane.setTranslation(0, 0, -0.01);
backPlane.setParentId(this.elementId);
+ backPlane.setFill(new api.NoFill());
ui.addElement(backPlane);
this.updateState();
« no previous file with comments | « chrome/browser/android/vr_shell/ui_elements.cc ('k') | chrome/browser/resources/vr_shell/vr_shell_ui_api.js » ('j') | no next file with comments »
@@ -51,14 +51,14 @@ var vrShellUi = (function() {
element.setTranslation(0, 0, -this.BROWSING_SCREEN_DISTANCE);
this.elementId = ui.addElement(element);
- // Place an invisible but hittable plane behind the content quad, to keep
- // the reticle roughly planar with the content if near content.
+ // Place an invisible (fill none) but hittable plane behind the content
+ // quad, to keep the reticle roughly planar with the content if near
+ // content.
let backPlane = new api.UiElement(0, 0, 0, 0);

Powered by Google App Engine
This is Rietveld 408576698